WalletDialogBuilders class

Holds optional custom builders for each wallet dialog. If a builder is null, the default premium UI is used. Set via Web3WalletConfig(dialogBuilders: ...) or WalletDialogService.instance.setBuilders(...).

Constructors

WalletDialogBuilders({ConnectDialogBuilder? connect, SignDialogBuilder? sign, TransactionDialogBuilder? transaction, SwitchNetworkDialogBuilder? switchNetwork, AddNetworkDialogBuilder? addNetwork})
const

Properties

addNetwork AddNetworkDialogBuilder?
final
connect ConnectDialogBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sign SignDialogBuilder?
final
switchNetwork SwitchNetworkDialogBuilder?
final
transaction TransactionDialogBuilder?
final

Methods

copyWith({ConnectDialogBuilder? connect, SignDialogBuilder? sign, TransactionDialogBuilder? transaction, SwitchNetworkDialogBuilder? switchNetwork, AddNetworkDialogBuilder? addNetwork}) WalletDialogBuilders
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited