UnauthorizedException class

Unauthorized (code 4100).

Inheritance

Constructors

UnauthorizedException([String message = 'Unauthorized'])

Properties

code int
code.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJson.
inherited
toString() String
toString.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited