WalletException class

Base wallet exception with EIP-1193 code.

Implemented types
Implementers

Constructors

WalletException(String message, {int code = -32603})
EIP-1193 error codes: 4001 user rejected, 4100 unauthorized, 4200 unsupported, 4900 disconnected, -32602 invalid params, -32603 internal

Properties

code int
code.
final
hashCode int
The hash code for this object.
no setterinherited
message String
message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJson.
toString() String
toString.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited