NetworkConfig class

EVM network configuration.

Constructors

NetworkConfig({required String chainId, required String chainName, NativeCurrency? nativeCurrency, required List<String> rpcUrls, List<String>? blockExplorerUrls, List<String>? iconUrls})
Public member.
NetworkConfig.fromJson(Map<String, dynamic> json)
factory

Properties

blockExplorerUrls → List<String>?
blockExplorerUrls.
final
chainId → String
chainId.
final
chainName → String
chainName.
final
hashCode → int
The hash code for this object.
no setterinherited
iconUrls → List<String>?
iconUrls.
final
nativeCurrency → NativeCurrency?
nativeCurrency.
final
rpcUrls → List<String>
rpcUrls.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toJson.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited