WalletState class

Current wallet connection state.

Constructors

WalletState({String? address, bool isConnected = false, required String chainId})
Public member.
WalletState.fromJson(Map<String, dynamic> json)
factory

Properties

address → String?
address.
final
chainId → String
chainId.
final
hashCode → int
The hash code for this object.
no setterinherited
isConnected → bool
isConnected.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? address, bool? isConnected, String? chainId}) → WalletState
Public member.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toJson.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited