ValidationUtils class

Validation helpers for addresses and hex.

Constructors

ValidationUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isValidAddress(String address) → bool
isValidAddress.
isValidHexData(String data) → bool
isValidHexData.
isValidHexValue(String value) → bool
isValidHexValue.