WalletDialogTheme class
Premium theming for wallet dialogs – minimal, trust-focused, Material 3 inspired.
Supports light (default) and dark via WalletDialogTheme.dark().
Constructors
- WalletDialogTheme({bool isDark = false, Color textColor = const Color(0xFF0F172A), Color secondaryTextColor = const Color(0xFF64748B), Color borderColor = const Color(0xFFE2E8F0), Color backgroundColor = Colors.white, Color surfaceColor = const Color(0xFFF8FAFC), Color cardColor = const Color(0xFFFFFFFF), Color primaryColor = const Color(0xFF6366F1), Color onPrimaryColor = Colors.white, Color warningColor = const Color(0xFFF59E0B), Color successColor = const Color(0xFF10B981), Color shadowColor = const Color(0x0F0F172A), TextStyle headerStyle = const TextStyle(fontSize: 20, fontWeight: FontWeight.w800, color: Color(0xFF0F172A), letterSpacing: -0.6, height: 1.2), TextStyle titleStyle = const TextStyle(fontSize: 13, fontWeight: FontWeight.w600, color: Color(0xFF64748B), letterSpacing: 0.6), TextStyle labelStyle = const TextStyle(fontSize: 11, fontWeight: FontWeight.w700, color: Color(0xFF64748B), letterSpacing: 0.8), TextStyle valueStyle = const TextStyle(fontSize: 14, fontWeight: FontWeight.w600, color: Color(0xFF0F172A), letterSpacing: -0.2, height: 1.4), TextStyle captionStyle = const TextStyle(fontSize: 12, fontWeight: FontWeight.w500, color: Color(0xFF64748B), height: 1.5), ButtonConfig? buttonConfirmStyle, ButtonConfig? buttonRejectStyle, EdgeInsets dialogPadding = const EdgeInsets.fromLTRB(20, 12, 20, 24), EdgeInsets contentPadding = const EdgeInsets.symmetric(horizontal: 20), double itemSpacing = 14.0, double borderRadius = 20.0, double elevation = 0})
- WalletDialogTheme.dark({Color primaryColor = const Color(0xFF818CF8), Color backgroundColor = const Color(0xFF0F172A), Color surfaceColor = const Color(0xFF1E293B), Color cardColor = const Color(0xFF1E293B), Color borderColor = const Color(0xFF334155), Color textColor = const Color(0xFFF1F5F9), Color secondaryTextColor = const Color(0xFF94A3B8), Color shadowColor = const Color(0x40000000)})
-
factory
Properties
- backgroundColor → Color
-
final
- borderColor → Color
-
final
- borderRadius → double
-
final
-
final
-
final
- captionStyle → TextStyle
-
final
- cardColor → Color
-
final
- contentPadding → EdgeInsets
-
final
- dialogPadding → EdgeInsets
-
final
- elevation → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerStyle → TextStyle
-
final
- isDark → bool
-
final
- itemSpacing → double
-
final
- labelStyle → TextStyle
-
final
- onPrimaryColor → Color
-
final
- primaryColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryTextColor → Color
-
final
- shadowColor → Color
-
final
- successColor → Color
-
final
- surfaceColor → Color
-
final
- textColor → Color
-
final
- titleStyle → TextStyle
-
final
- valueStyle → TextStyle
-
final
- warningColor → Color
-
final
Methods
-
copyWith(
{bool? isDark, Color? textColor, Color? secondaryTextColor, Color? borderColor, Color? backgroundColor, Color? surfaceColor, Color? cardColor, Color? primaryColor, TextStyle? headerStyle, TextStyle? labelStyle, TextStyle? valueStyle, ButtonConfig? buttonConfirmStyle, ButtonConfig? buttonRejectStyle, EdgeInsets? dialogPadding, EdgeInsets? contentPadding, double? itemSpacing, double? borderRadius}) → WalletDialogTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited