Web3WalletConfig class
Configuration for Web3WebView wallet bridge.
Constructors
-
Web3WalletConfig({String? privateKey, Web3Signer? signer, String? name, String? icon, String? id, NetworkConfig? currentNetwork, List<
NetworkConfig> ? supportNetworks, bool? isDebug, WalletDialogTheme? dialogTheme, WalletDialogTheme? darkDialogTheme, WalletDialogBuilders? dialogBuilders, dynamic onError(JsonRpcMethod method, List? params, String message)?}) - Public member.
Properties
- currentNetwork → NetworkConfig?
-
currentNetwork.
final
- darkDialogTheme → WalletDialogTheme?
-
Dark variant – auto-used when system is dark. If null, auto-derived from dialogTheme.
final
- dialogBuilders → WalletDialogBuilders?
-
Optional custom builders to completely replace the default premium UI.
If
null, the built-in premium + dark-adaptive dialogs are used. Example:WalletDialogBuilders(connect: (ctx, ...) => showYourWidget(...)).final - dialogTheme → WalletDialogTheme?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSigner → bool
-
Whether a signer is available (privateKey or external signer).
no setter
- icon → String?
-
icon.
final
- id → String?
-
id.
final
- isDebug → bool?
-
isDebug.
final
- isReadOnly → bool
-
Whether the config is read-only (no signing capability).
no setter
- name → String?
-
name.
final
- onError → dynamic Function(JsonRpcMethod method, List? params, String message)?
-
final
- privateKey → String?
-
Optional hex private key (32 bytes,
0xoptional).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signer → Web3Signer?
-
External signer (WalletConnect, Secure Enclave, etc.).
final
-
supportNetworks
→ List<
NetworkConfig> ? -
supportNetworks.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited