TypedData class
TypedData – see README for usage.
Constructors
Properties
-
domain
→ Map<
String, dynamic> -
domain.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
message
→ Map<
String, dynamic> -
message.
final
- primaryType → String
-
primaryType.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
types
→ Map<
String, dynamic> -
types.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited