TransactionHandler class
Prepares, signs and sends EVM transactions.
Constructors
- TransactionHandler(Web3Client _web3client, Credentials _credentials, int _chainId)
- TransactionHandler.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
estimateGas(
Map< String, dynamic> txParams) → Future<BigInt> -
Estimates gas for
txParamswith 20% buffer. -
handleTransaction(
Map< String, dynamic> txParams, {bool waitForConfirmation = false}) → Future<String> -
EIP-1193: eth_sendTransaction must return hash immediately, not wait for mining.
waitForConfirmationis opt-in for callers that need blocking behavior. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited