AppUtils class

AppUtils – see README for usage.

Constructors

AppUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

copyToClipboard(String text, [String? message]) Future<void>
copyToClipboard.
formatCoin(dynamic amount, {String symbol = '', int? decimalDigits = 2, bool leftSymbol = false, bool useUnitSuffix = false}) String
Public member.
removeUnnecessaryZeros(String formatted, String symbol, bool leftSymbol) String
Public member.