onNavigationResponse property
Future<NavigationResponseAction?> Function(InAppWebViewController controller, )?
onNavigationResponse
final
Called when a web view asks for permission to navigate to new content after the response to the navigation request is known.
navigationResponse represents the navigation response.
NOTE: available only on iOS. In order to be able to listen this event, you need to set IOSInAppWebViewSettings.useOnNavigationResponse option to true.
Official iOS API: https://developer.apple.com/documentation/webkit/wknavigationdelegate/1455643-webview
Implementation
final Future<NavigationResponseAction?> Function(
InAppWebViewController controller,
NavigationResponse navigationResponse)? onNavigationResponse;